#[repr(C)]pub struct CompactPair<A, B> {
pub _phantom_0: PhantomData<UnsafeCell<A>>,
pub _phantom_1: PhantomData<UnsafeCell<B>>,
pub mFirst: A,
pub mSecond: B,
}Expand description
CompactPair is the logical concatenation of an instance of A with an instance B. Space is conserved when possible.
In general if space conservation is not critical is preferred to use std::pair.
Fields
_phantom_0: PhantomData<UnsafeCell<A>>_phantom_1: PhantomData<UnsafeCell<B>>mFirst: AmSecond: BTrait Implementations
Sourceimpl<A, B> Clone for CompactPair<A, B>
impl<A, B> Clone for CompactPair<A, B>
Sourcefn clone(&self) -> CompactPair<A, B>
fn clone(&self) -> CompactPair<A, B>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A, B> Debug for CompactPair<A, B>
impl<A, B> Debug for CompactPair<A, B>
Sourceimpl<A, B> PartialEq for CompactPair<A, B>
impl<A, B> PartialEq for CompactPair<A, B>
Sourcefn eq(&self, other: &CompactPair<A, B>) -> bool
fn eq(&self, other: &CompactPair<A, B>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<A, B> Copy for CompactPair<A, B>
impl<A, B> StructuralPartialEq for CompactPair<A, B>