#[repr(C)]pub struct CorruptionCanaryForStatics {
pub mValue: usize,
}Expand description
A version of CorruptionCanary that is suitable as a member of objects that are statically allocated.
Fields
mValue: usizeTrait Implementations
Sourceimpl Debug for CorruptionCanaryForStatics
impl Debug for CorruptionCanaryForStatics
Sourceimpl PartialEq for CorruptionCanaryForStatics
impl PartialEq for CorruptionCanaryForStatics
Sourcefn eq(&self, other: &CorruptionCanaryForStatics) -> bool
fn eq(&self, other: &CorruptionCanaryForStatics) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CorruptionCanaryForStatics