pub type TimeStamp_DurationType = BaseTimeDuration;Expand description
Instances of this class represent the length of an interval of time. Negative durations are allowed, meaning the end is before the start.
Internally the duration is stored as a system-dependent unit.
The ValueCalculator template parameter determines how arithmetic operations are performed on the integer count of ticks (mValue).
Aliased Type
#[repr(C)]pub struct TimeStamp_DurationType {
pub mValue: i64,
}Fields
mValue: i64